<fieldset class="module aligned {{ fieldset.classes }}">
    {% if fieldset.name %}<h2>{{ fieldset.name }}</h2>{% endif %}
    {% if fieldset.description %}
        <div class="description">{{ fieldset.description|safe }}</div>
    {% endif %}
    {% for line in fieldset %}
        <div class="form-row{% if line.fields|length_is:'1' and line.errors %} errors{% endif %}{% for field in line %} {{ field.field.name }}{% endfor %}">
            {% if line.fields|length_is:'1' %}{{ line.errors }}{% endif %}
            {% for field in line %}
                <div{% if not line.fields|length_is:'1' %} class="field-box{% if not field.is_readonly and field.errors %} errors{% endif %}"{% endif %}>
                    {% if not line.fields|length_is:'1' and not field.is_readonly %}{{ field.errors }}{% endif %}
                    {% if field.is_checkbox %}
                        {{ field.field }}{{ field.label_tag }}
                    {% else %}
                        {{ field.label_tag }}
                        {% if field.is_readonly %}
                            {% if field.field.name == "content" %}
                                <textarea id=template_preview>{{ field.contents }}</textarea>
                                <script type="text/javascript">
                                    var editor = CodeMirror.fromTextArea('template_preview', {
                                            path: "{{STATIC_URL}}dbtemplates/js/",
                                            parserfile: "parsedjango.js",
                                            stylesheet: "{{STATIC_URL}}dbtemplates/css/django.css",
                                            continuousScanning: 500,
                                            height: "40.2em",
                                            tabMode: "shift",
                                            indentUnit: 4,
                                            lineNumbers: true,
                                            readOnly: 'nocursor',
                                        });
                                </script>
                            {% else %}
                                <p>{{ field.contents }}</p>
                            {% endif %}
                        {% else %}
                            {{ field.field }}
                        {% endif %}
                    {% endif %}
                    {% if field.field.help_text and not field.is_readonly %}
                        <p class="help">{{ field.field.help_text|safe }}</p>
                    {% endif %}
                </div>
            {% endfor %}
        </div>
    {% endfor %}
</fieldset>
